"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTokenCirculatingSupply = exports.isOptIn = exports.getAsaBalance = exports.getCreatedAssets = void 0;
function getAccountAttribute(account, name) {
    return account[name];
}
async function getAssets(client, address) {
    const account = await client.accountInformation(address).do();
    const assets = getAccountAttribute(account, 'assets');
    return assets;
}
async function findAsset(client, address, asaId) {
    const assets = (await getAssets(client, address));
    return assets.find((asa) => asa['asset-id'] === asaId);
}
async function getCirculatingSupply(client, asaId) {
    const asa = await client.getAssetByID(asaId).do();
    const asaParams = asa['params'];
    const reserve = asaParams.reserve;
    const reserveBalance = await getAsaBalance(client, reserve, asaId);
    const total = asaParams.total;
    const circulating = total - reserveBalance;
    return circulating;
}
async function getCreatedAssets(client, address) {
    const account = await client.accountInformation(address).do();
    const createdAssets = getAccountAttribute(account, 'created-assets');
    return createdAssets;
}
exports.getCreatedAssets = getCreatedAssets;
async function getAsaBalance(client, address, asaId) {
    const asa = await findAsset(client, address, asaId);
    const amount = asa ? asa['amount'] : 0;
    return amount;
}
exports.getAsaBalance = getAsaBalance;
async function isOptIn(client, address, asaId) {
    const asa = await findAsset(client, address, asaId);
    const amount = asa ? asa['amount'] : -1;
    return amount != -1;
}
exports.isOptIn = isOptIn;
async function getTokenCirculatingSupply(client, asaId) {
    const circulating = await getCirculatingSupply(client, asaId);
    return circulating;
}
exports.getTokenCirculatingSupply = getTokenCirculatingSupply;
//# sourceMappingURL=assets.js.map