"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAssetMetadata = exports.getAssetIdByMetadataHash = void 0;
const crypto_1 = require("crypto");
const assets_1 = require("./assets");
function getAndDecodeNote(txRecord) {
    const txNote = txRecord['note'];
    if (!txNote)
        throw new Error('Asset do not have note msg');
    const decodedNote = Buffer.from(txNote, 'base64').toString('utf8');
    try {
        return JSON.parse(decodedNote);
    }
    catch (e) {
        throw new Error('Asset not compatible with ARC-69');
    }
}
async function getAsaCreationTx(indexer, assetId) {
    const assetTx = await indexer.lookupAssetTransactions(assetId).do();
    const createTx = assetTx['transactions'][0];
    return createTx;
}
async function getAssetIdByMetadataHash(client, hashKey, creator) {
    const hash = (0, crypto_1.createHash)('sha256').update(hashKey, 'utf8').digest('base64');
    const assets = (await (0, assets_1.getCreatedAssets)(client, creator));
    const asset = assets.find((asa) => asa['params']['metadata-hash'] == hash);
    return asset == undefined ? -1 : asset.index;
}
exports.getAssetIdByMetadataHash = getAssetIdByMetadataHash;
async function getAssetMetadata(indexer, assetId) {
    const createTx = await getAsaCreationTx(indexer, assetId);
    return getAndDecodeNote(createTx);
}
exports.getAssetMetadata = getAssetMetadata;
//# sourceMappingURL=metadata.js.map