"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const accounts = require("../index");
const testConfig_1 = require("./testConfig");
describe('AccountsTest: happy path', () => {
    it('Should return True if the address is valid', async () => {
        const isValid = await accounts.validateAddress(testConfig_1.address);
        expect(isValid).toBe(true);
    });
    it('Should return False if the address is not valid', async () => {
        const isValid = await accounts.validateAddress(testConfig_1.nonValidAddress);
        expect(isValid).toBe(false);
    });
    it('Should return the balance in algos for the address', async () => {
        const balance = await accounts.getBalanceAlgos(testConfig_1.client, testConfig_1.address);
        expect(balance).toBe(19.995);
    });
    it('Should return the balance in microalgos for the address', async () => {
        const balance = await accounts.getBalanceMicroalgos(testConfig_1.client, testConfig_1.address);
        expect(balance).toBe(19995000);
    });
    it('Should return zero if the address has no balance', async () => {
        const balance = await accounts.getBalanceAlgos(testConfig_1.client, testConfig_1.nonBalAddress);
        expect(balance).toBe(0);
        const balance2 = await accounts.getBalanceMicroalgos(testConfig_1.client, testConfig_1.nonBalAddress);
        expect(balance2).toBe(0);
    });
    it('Should return the minimum balance for the address', async () => {
        const minBalance = await accounts.getMinBalance(testConfig_1.client, testConfig_1.address);
        expect(minBalance).toBe(0.5);
    });
});
describe('AccountsTest: unhappy path', () => {
    it('Should throw an error if the address is not valid: getBalanceMicroalgo', async () => {
        expect.assertions(1);
        try {
            await accounts.getBalanceMicroalgos(testConfig_1.client, testConfig_1.nonValidAddress);
        }
        catch (e) {
            expect(e).toEqual(Error('Network request error. Received status 400: failed to parse the address'));
        }
    });
    it('Should throw an error if the address is not valid: getBalanceAlgos', async () => {
        expect.assertions(1);
        try {
            await accounts.getBalanceAlgos(testConfig_1.client, testConfig_1.nonValidAddress);
        }
        catch (e) {
            expect(e).toEqual(Error('Network request error. Received status 400: failed to parse the address'));
        }
    });
    it('Should throw an error if the address is not valid: getMinBalance', async () => {
        expect.assertions(1);
        try {
            await accounts.getMinBalance(testConfig_1.client, testConfig_1.nonValidAddress);
        }
        catch (e) {
            expect(e).toEqual(Error('Network request error. Received status 400: failed to parse the address'));
        }
    });
});
//# sourceMappingURL=accounts.test.js.map