"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assets = require("../index");
const testConfig_1 = require("./testConfig");
describe('AssetsTest: Happy Path', () => {
    it('Should get all the asset crated by a waller', async () => {
        const createdAssets = await assets.getCreatedAssets(testConfig_1.client, testConfig_1.address);
        expect(createdAssets.length).toEqual(3);
    });
    it('Should get all the asset crated by a waller', async () => {
        const createdAssets = await assets.getCreatedAssets(testConfig_1.client, testConfig_1.nonBalAddress);
        expect(createdAssets.length).toEqual(0);
    });
    it('Should get the asa balance of one asset', async () => {
        const createdAssets = await assets.getCreatedAssets(testConfig_1.client, testConfig_1.address);
        const asaId = createdAssets[0].index;
        const asaBalance = await assets.getAsaBalance(testConfig_1.client, testConfig_1.address, asaId);
        expect(asaBalance).toEqual(1);
    });
    it('Should return zero if the adders do not have that asset', async () => {
        const asaBalance = await assets.getAsaBalance(testConfig_1.client, testConfig_1.nonBalAddress, testConfig_1.asaId);
        expect(asaBalance).toEqual(0);
    });
    it('Should return true if the account is optIn', async () => {
        const isOptIn = await assets.isOptIn(testConfig_1.client, testConfig_1.address, testConfig_1.asaId);
        expect(isOptIn).toEqual(true);
    });
    it('Should return false if the account is not optIn', async () => {
        const isOptIn = await assets.isOptIn(testConfig_1.client, testConfig_1.nonBalAddress, testConfig_1.asaId);
        expect(isOptIn).toEqual(false);
    });
    it('Should return the circulating supply of the token', async () => {
        const circulating = await assets.getTokenCirculatingSupply(testConfig_1.client, testConfig_1.testId);
        expect(circulating).toEqual(5000000000);
    });
});
describe('AssetsTest: Unhappy Path', () => {
    it('Should throw an error if the address is not valid: getCreatedAssets', async () => {
        await expect(assets.getCreatedAssets(testConfig_1.client, testConfig_1.nonValidAddress)).rejects.toThrow();
    });
    it('Should throw an error if the address is not valid: getAsaBalance', async () => {
        const createdAssets = await assets.getCreatedAssets(testConfig_1.client, testConfig_1.address);
        const asaId = createdAssets[0].index;
        await expect(assets.getAsaBalance(testConfig_1.client, testConfig_1.nonValidAddress, asaId)).rejects.toThrow();
    });
    it('Should throw an error if the address is not valid: isOptIn', async () => {
        await expect(assets.isOptIn(testConfig_1.client, testConfig_1.nonValidAddress, testConfig_1.asaId)).rejects.toThrow();
    });
});
//# sourceMappingURL=assets.test.js.map